# Show both continuous and categorical stats
all <- Tainan2020datasetDescriptiveStatistics(show = "all")
# Mean value for the OS_months columns
all$continuous["Mean", "OS_months"]
# Min, Median and Max value for ALL the numeric columns
all$continuous[c("Min","Median","Max"),]
# Get the frequency table of the third categorical column
all$categorical[[3]]
# Only continuous variables
cont <- Tainan2020datasetDescriptiveStatistics("continuous")
# Statistics for age_years column
cont[, "age_years"]
# Only categorical variables
cat <- Tainan2020datasetDescriptiveStatistics("categorical")
# Frequency values for all factors of the first categorical column
cat[[1]][,"Freq"]
# Statistics for the Yes factor of the first categorical column
cat[[1]]["Yes",]
# Frequency of the No factor, a value of the first categorical column
cat[[1]]["No", "Freq"]
Run the code above in your browser using DataLab