Learn R Programming

glioblastomaEHRsData (version 1.1.0)

descriptiveTableMunich2019dataset: Descriptive statistics table for the munich2019dataset

Description

Function to create, display and optionally export a table containing descriptive statistics for the munich2019dataset.
The table is created using the table1 package and is grouped by survival status.

Usage

descriptiveTableMunich2019dataset(savePath = NULL)

Value

A 'table1' object containing descriptive statistics grouped by survival status.

Arguments

savePath

Character (optional). String specifying the path and filename for exporting the table.

  • If NULL (default), the table will not be exported.

  • If "" (empty string), the table will be saved in the working directory using a default name.

  • Expected format: 'filepath/filename.extensions' where:

    • filepath is the directory (must already exist), default is the working directory;

    • filename is the name of the file, default to 'table_munich2019dataset_timestamp.png';

    • extension must be one of png, pdf html and must be specified, unless using the default filename.

See Also

table1::table1()

Examples

Run this code
# Create and display the table, without saving anything
descriptiveTableMunich2019dataset()

# \donttest{
# Create, display and save the table giving a path, filename and extension
descriptiveTableMunich2019dataset(savePath = "tables/munich_web_table.html")

# Create, display and save the table giving a path, filename and extension
descriptiveTableMunich2019dataset(savePath = "tables/munich_table.pdf")

# Create, display and save the table giving only the path, default name will be used
descriptiveTableMunich2019dataset(savePath = "tables/")

# Create, display and save the table giving a path and filename, default extension will be used
descriptiveTableMunich2019dataset(savePath = "tables/munich_table")
# }


Run the code above in your browser using DataLab