# Create and display the table, without saving anything
descriptiveTableTainan2020dataset()
# \donttest{
# Create, display and save the table giving a path, filename and extension
descriptiveTableTainan2020dataset(savePath = "tables/tainan_web_table.html")
# Create, display and save the table giving a path, filename and extension
descriptiveTableTainan2020dataset(savePath = "tables/tainan_table.pdf")
# Create, display and save the table giving only the path, default name will be used
descriptiveTableTainan2020dataset(savePath = "tables/")
# Create, display and save the table giving a path and filename,default extension will be used
descriptiveTableTainan2020dataset(savePath = "tables/tainan_table")
# }
Run the code above in your browser using DataLab