Learn R Programming

glioblastomaEHRsData (version 1.1.0)

descriptiveTableUtrecht2019dataset: Descriptive statistic table for the utrecht2019dataset

Description

Function to create, display and optionally export a table containing descriptive statistics for the utrecht2019dataset
The table is created using the table1 package and is grouped by survival status.

Usage

descriptiveTableUtrecht2019dataset(savePath = NULL)

Value

A 'table1' object containing descriptive statistics grouped by survival status.

Arguments

savePath

Character (optional). String specifying the path and filename for exporting the table.

  • If NULL (default), the table will not be exported.

  • If "" (empty string), the table will be saved in the working directory using a default name.

  • Expected format: 'filepath/filename.extensions' where:

    • filepath is the directory (must already exist), default is the working directory;

    • filename is the name of the file, default to 'table_utrecht2019dataset_timestamp.png';

    • extension must be one of png, pdf or html and must be specified, unless using the default filename.

See Also

table1::table1()

Examples

Run this code
# Create and display the table, without saving anything
descriptiveTableUtrecht2019dataset()

# \donttest{
# Create, display and save the table giving a path, filename and extension
descriptiveTableUtrecht2019dataset(savePath = "tables/utrecht_web_table.html")

# Create, display and save the table giving a path, filename and extension
descriptiveTableUtrecht2019dataset(savePath = "tables/utrecht_table.pdf")

# Create, display and save the table giving only the path, default name will be used
descriptiveTableUtrecht2019dataset(savePath = "tables/")

# Create, display and save the table giving a path and filename,default extension will be used
descriptiveTableUtrecht2019dataset(savePath = "tables/utrecht_table")

# }

Run the code above in your browser using DataLab