Learn R Programming

glioblastomaEHRsData (version 1.1.0)

global_variables: Declarations for glibal variables

Description

This file is used to suppress global variables NOTEs while running 'R CMD check', these variables are used as internal datasets in the package functions. They are declared in the 'data/' folder and are automatically loaded using 'lazydata = TRUE'

Usage

global_variables

Arguments

Format

An object of class NULL of length 0.

Details

@keywords internal @name global_variables