# Univariate plot without saving
plotTainan2020dataset("TMZ_based_chemo_yes1_no0")
# Bivariate plot without saving
plotTainan2020dataset("PFS_months", "OS_months")
# \donttest{
# Bivariate plot saved in the specified directory with the chosen name and extension
plotTainan2020dataset("age_years", "chemo_yes1_no0", savePath = NA)
# Bivariate plot saved in the working directory with the chosen name and extension
plotTainan2020dataset("PFS_months", "OS_months", savePath = NA)
# Bivariate plot saved in a path directory with default name and extension
plotTainan2020dataset("PFS_months", "radiation_dose_Gy", savePath = NA)
# }
Run the code above in your browser using DataLab