# Show both continuous and categorical stats
all <- Munich2019datasetDescriptiveStatistics(show = "all")
# Mean value for the OS_months columns
all$continuous["Mean", "OS_months"]
# Min, Median and Max value for ALL the numeric columns
all$continuous[c("Min","Median","Max"),]
# Get the frequency table of the third categorical column
all$categorical[[3]]
# Only continuous variables
cont <- Munich2019datasetDescriptiveStatistics("continuous")
# Statistics for age_years column
cont[, "age_years"]
# Only categorical variables
cat <- Munich2019datasetDescriptiveStatistics("categorical")
# Frequency values for all factors of the first categorical column
cat[[1]][,"Freq"]
# Statistics for the Low factor of the first categorical column
cat[[1]]["Low",]
# Frequency of the Low factor, a value of the first categorical column
cat[[1]]["Low", "Freq"]
Run the code above in your browser using DataLab