# Show both continuous and categorical stats
all <- Utrecht2019datasetDescriptiveStatistics(show = "all")
# Mean value for the OS_months columns
all$continuous["Mean", "OS_months"]
# Min, Median and Max value for ALL the numeric columns
all$continuous[c("Min","Median","Max"),]
# Get the frequency table of the third categorical column
all$categorical[[3]]
# Only continuous variables
cont <- Utrecht2019datasetDescriptiveStatistics("continuous")
# Statistics for age_years column
cont[, "age_years"]
# Only categorical variables
cat <- Utrecht2019datasetDescriptiveStatistics("categorical")
# Frequency values for all factors of the second categorical column
cat[[2]][,"Freq"]
# Statistics for the Yes factor of the second categorical column
cat[[2]]["Monotherapy",]
# Frequency of the No factor, a value of the second categorical column
cat[[2]]["RT+TMZ", "Freq"]
Run the code above in your browser using DataLab