# Create and display the table, without saving anything
descriptiveTableMunich2019dataset()
# \donttest{
# Create, display and save the table giving a path, filename and extension
descriptiveTableMunich2019dataset(savePath = "tables/munich_web_table.html")
# Create, display and save the table giving a path, filename and extension
descriptiveTableMunich2019dataset(savePath = "tables/munich_table.pdf")
# Create, display and save the table giving only the path, default name will be used
descriptiveTableMunich2019dataset(savePath = "tables/")
# Create, display and save the table giving a path and filename, default extension will be used
descriptiveTableMunich2019dataset(savePath = "tables/munich_table")
# }
Run the code above in your browser using DataLab