# Create and display the table, without saving anything
descriptiveTableUtrecht2019dataset()
# \donttest{
# Create, display and save the table giving a path, filename and extension
descriptiveTableUtrecht2019dataset(savePath = "tables/utrecht_web_table.html")
# Create, display and save the table giving a path, filename and extension
descriptiveTableUtrecht2019dataset(savePath = "tables/utrecht_table.pdf")
# Create, display and save the table giving only the path, default name will be used
descriptiveTableUtrecht2019dataset(savePath = "tables/")
# Create, display and save the table giving a path and filename,default extension will be used
descriptiveTableUtrecht2019dataset(savePath = "tables/utrecht_table")
# }
Run the code above in your browser using DataLab