global_variables: Declarations for glibal variables
Description
This file is used to suppress global variables NOTEs while running 'R CMD check',
these variables are used as internal datasets in the package functions.
They are declared in the 'data/' folder and are automatically loaded using
'lazydata = TRUE'