# Univariate plot without saving
plotMunich2019dataset("age_years")
# Bivariate plot without saving
plotMunich2019dataset("cHsp70_low0_high1", "sex_male0_female1")
# \donttest{
# Bivariate plot saved in the path directory with the chosen name and extension
plotMunich2019dataset("age_years", "sex_male0_female1", savePath = NA)
# Univariate plot saved in the working directory with the chosen name and extension
plotMunich2019dataset("sex_male0_female1", savePath = NA)
# Univariate plot saved in the path directory with default name and extension
plotMunich2019dataset("MGMTmethylation_methylated1_unmethylated0", savePath = NA)
# }
Run the code above in your browser using DataLab